@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
-static const char RCSID[]="$Id: colour-sel-gtk.c,v 1.20 2003/10/26 04:32:51 jmd Exp $";
+static const char RCSID[]="$Id: colour-sel-gtk.c,v 1.21 2003/12/29 12:03:28 uid66691 Exp $";
 
 
 
@@ -29,7 +29,7 @@ static const char RCSID[]="$Id: colour-sel-gtk.c,v 1.20 2003/10/26 04:32:51 jmd
 #include "widget-set.h"
 #include "select.h"
 
-#if HAVE_LIBGDK_PIXBUF
+#if HAVE_LIBGDK_PIXBUF_2_0
 # include <gdk-pixbuf/gdk-pixbuf.h>
 #endif
 
@@ -92,7 +92,7 @@ static int selected_swatch=0;
 static GdkGC *the_gcs[6]={0,0,0,0,0,0};
 
 struct swatch_rendering {
-#if HAVE_LIBGDK_PIXBUF
+#if HAVE_LIBGDK_PIXBUF_2_0
   GdkPixbuf *pixbuf;
 #endif
   GLfloat color[4];
@@ -162,7 +162,7 @@ set_swatch_image(gint theSwatch, const gchar *filename, GtkWidget *fs )
 {
   GLuint texName;
 
-#if HAVE_LIBGDK_PIXBUF
+#if HAVE_LIBGDK_PIXBUF_2_0
 
   GdkPixbuf *pixbuf ; 
   GError *gerr = 0;
@@ -569,7 +569,7 @@ drag_data_received(GtkWidget *widget,
 
     }
     break ; 
-#if HAVE_LIBGDK_PIXBUF
+#if HAVE_LIBGDK_PIXBUF_2_0
   case RDRAG_FILELIST:
     {
       gchar **s=0;
@@ -713,7 +713,7 @@ colour_select_menu( GtkWidget *w,   gpointer   data )
   image_select_vbox = gtk_vbox_new(FALSE,BOX_PADDING);
   image_select_hbox = gtk_hbox_new(FALSE,BOX_PADDING);
 
-#if HAVE_LIBGDK_PIXBUF
+#if HAVE_LIBGDK_PIXBUF_2_0
   {
   frame = gtk_frame_new(_("Image"));
   button_use_image = gtk_button_new_with_mnemonic(_("Se_lect"));
@@ -974,7 +974,7 @@ draw_swatch(GtkWidget *widget, GdkEventExpose *event, gpointer data)
     break ;
 
   case IMAGED:
-#if HAVE_LIBGDK_PIXBUF
+#if HAVE_LIBGDK_PIXBUF_2_0
     { 
       GdkPixbuf *scaled_pixbuf=0;
       gint width, height;
