@@ -19,7 +19,7 @@
 #ifndef DRW_BLOCKS_H
 #define DRW_BLOCKS_H
 
-#include "blocks.h"
+#include "cube.h"
 #include <GL/gl.h>
 #include "textures.h"
 
